==> haskell-data-serializer-0.3.4-33-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-data-serializer.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: data-serializer
version: 0.3.4
id: data-serializer-0.3.4-3yDBFCn6YIOD8xnAYLZ9Z3
key: data-serializer-0.3.4-3yDBFCn6YIOD8xnAYLZ9Z3
license: BSD-3-Clause
copyright: 2016 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability: experimental
homepage: https://github.com/mvv/data-serializer
synopsis: Common API for serialization libraries
description:
    This package provides a common API for serialization libraries like
    <http://hackage.haskell.org/package/binary binary> and
    <http://hackage.haskell.org/package/cereal cereal>.
category: Data
abi: 5e5675475705e18e272ad3af7c81c93f
exposed: True
exposed-modules:
    Data.Deserializer Data.Serializer
import-dirs: /usr/lib/ghc-8.4.3/site-local/data-serializer-0.3.4
library-dirs: /usr/lib/ghc-8.4.3/site-local/data-serializer-0.3.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/data-serializer-0.3.4
hs-libraries: HSdata-serializer-0.3.4-3yDBFCn6YIOD8xnAYLZ9Z3
depends:
    base-4.11.1.0 bytestring-0.10.8.2 binary-0.8.5.1
    cereal-0.5.7.0-GeNBgd8Wa452X4EoKnwsnC
    data-endian-0.1.1-Hq7bxn6bh65QNiKhqKtek
    parsers-0.12.9-LxMgMM1WdwxA4SaFpxpOmn
    split-0.2.3.3-DYHuRk05Zl3FsXrGVgC4fG
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             binary-0.8.5.1=0c28e4e382bf1405fd468e0d2a2b58e5
             cereal-0.5.7.0-GeNBgd8Wa452X4EoKnwsnC=5e7d9231d9563e623638bef60db7e501
             data-endian-0.1.1-Hq7bxn6bh65QNiKhqKtek=d9939c686c8812f32033853596341c48
             parsers-0.12.9-LxMgMM1WdwxA4SaFpxpOmn=caef24b1170c2fa24259b679fc10480e
             split-0.2.3.3-DYHuRk05Zl3FsXrGVgC4fG=cdf77c47c599317cfa01d2d98185c5d3
haddock-interfaces: /usr/share/doc/haskell-data-serializer/html/data-serializer.haddock
haddock-html: /usr/share/doc/haskell-data-serializer/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-data-serializer-0.3.4-37-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-data-serializer.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: data-serializer
version: 0.3.4
id: data-serializer-0.3.4-3xqgbu4X3I3AjYxZaw5Hr1
key: data-serializer-0.3.4-3xqgbu4X3I3AjYxZaw5Hr1
license: BSD-3-Clause
copyright: 2016 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability: experimental
homepage: https://github.com/mvv/data-serializer
synopsis: Common API for serialization libraries
description:
    This package provides a common API for serialization libraries like
    <http://hackage.haskell.org/package/binary binary> and
    <http://hackage.haskell.org/package/cereal cereal>.
category: Data
abi: e9a2bdf5369a72ad137f83b4db33a794
exposed: True
exposed-modules:
    Data.Deserializer Data.Serializer
import-dirs: /usr/lib/ghc-8.6.1/site-local/data-serializer-0.3.4
library-dirs: /usr/lib/ghc-8.6.1/site-local/data-serializer-0.3.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/data-serializer-0.3.4
hs-libraries: HSdata-serializer-0.3.4-3xqgbu4X3I3AjYxZaw5Hr1
depends:
    base-4.12.0.0 binary-0.8.6.0 bytestring-0.10.8.2
    cereal-0.5.7.0-2uER3Agem8P6aYfM1x47n8
    data-endian-0.1.1-8eI15msEBjH5vqdbWN68zz
    parsers-0.12.9-9naOFvDd4i64DWNFNLOkJ6
    split-0.2.3.3-9O3ah5XNSacJuZjDAE6BjK
haddock-interfaces: /usr/share/doc/haskell-data-serializer/html/data-serializer.haddock
haddock-html: /usr/share/doc/haskell-data-serializer/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
